@@ -35,9 +35,9 @@ public:
 	void setTrust(const gpgme_validity_t trust);
 
 protected:
-	bool nextLine(const QString &line) Q_DECL_OVERRIDE;
-	ts_boolanswer boolQuestion(const QString &line) Q_DECL_OVERRIDE;
-	bool preStart() Q_DECL_OVERRIDE;
+	bool nextLine(const QString &line) override;
+	ts_boolanswer boolQuestion(const QString &line) override;
+	bool preStart() override;
 
 private:
 	gpgme_validity_t m_trust;
