@@ -28,7 +28,7 @@ class KGpgDelSign: public KGpgUidTransaction {
 	Q_OBJECT
 
 	Q_DISABLE_COPY(KGpgDelSign)
-	KGpgDelSign() Q_DECL_EQ_DELETE;
+	KGpgDelSign() = delete;
 public:
 	/**
 	 * @brief construct a new transaction to delete signatures
@@ -69,8 +69,8 @@ public:
 	KGpgSignNode::List getSignIds(void) const;
 
 protected:
-	bool nextLine(const QString &line) Q_DECL_OVERRIDE;
-	ts_boolanswer boolQuestion(const QString &line) Q_DECL_OVERRIDE;
+	bool nextLine(const QString &line) override;
+	ts_boolanswer boolQuestion(const QString &line) override;
 
 private:
 	KGpgSignNode::List m_signids;	///< the list of ids to delete
