@@ -18,7 +18,7 @@
 #include <QString>
 #include <QStringList>
 
-#include <KUrl>
+#include <QUrl>
 
 #include "kgpgtransaction.h"
 
@@ -49,9 +49,9 @@ protected:
 	/**
 	 * @brief work with given file(s)
 	 * @param parent parent object
-	 * @param keys list of file locations to work with
+	 * @param files list of file locations to work with
 	 */
-	KGpgTextOrFileTransaction(QObject *parent, const KUrl::List &files, const bool allowChaining = false);
+	KGpgTextOrFileTransaction(QObject *parent, const QList<QUrl> &files, const bool allowChaining = false);
 
 public:
 	/**
@@ -66,9 +66,9 @@ public:
 	void setText(const QString &text);
 	/**
 	 * @brief set file locations to work with
-	 * @param keys list of file locations to work with
+	 * @param files list of file locations to work with
 	 */
-	void setUrls(const KUrl::List &files);
+	void setUrls(const QList<QUrl> &files);
 
 	/**
 	 * @brief get gpg info message
@@ -80,21 +80,21 @@ protected:
 	/**
 	 * @brief construct the command line of the process
 	 */
-	virtual bool preStart() Q_DECL_OVERRIDE;
-	virtual bool nextLine(const QString &line) Q_DECL_OVERRIDE;
+	bool preStart() override;
+	bool nextLine(const QString &line) override;
 	/**
 	 * @brief implement special handling for GnuPG return codes
 	 */
-	virtual void finish() Q_DECL_OVERRIDE;
+	void finish() override;
 
 	virtual QStringList command() const = 0;
 
-	const KUrl::List &getInputFiles() const;
+	const QList<QUrl> &getInputFiles() const;
 
 private:
 	QStringList m_tempfiles;
 	QStringList m_locfiles;
-	KUrl::List m_inpfiles;
+	QList<QUrl> m_inpfiles;
 	QString m_text;
 	QStringList m_messages;
 	bool m_closeInput;	///< if input channel of GnuPG should be closed after m_text is written
@@ -102,7 +102,7 @@ private:
 	void cleanUrls();
 
 private slots:
-	void postStart();
+	void postStart() override;
 };
 
 #endif // KGPGTEXTORFILETRANSACTION_H
