@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2016 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2016,2018 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -314,6 +314,12 @@ KGpgTransaction::askPassphrase(const QString &message)
 	return true;
 }
 
+void
+KGpgTransaction::setExpectedFingerprints(const QStringList &fingerprints)
+{
+	d->m_expectedFingerprints = fingerprints;
+}
+
 void
 KGpgTransaction::setGnuPGHome(const QString &home)
 {
@@ -397,17 +403,3 @@ void
 KGpgTransaction::newPassphraseEntered()
 {
 }
-
-bool KGpgTransaction::keyConsidered(const QString& line, const QStringList &fingerprints)
-{
-	if (!line.startsWith(QLatin1String("[GNUPG:] KEY_CONSIDERED ")))
-		return false;
-
-	const QStringList &parts = line.split(QLatin1Char(' '), QString::SkipEmptyParts);
-	if (parts.count() < 3)
-		setSuccess(KGpgTransaction::TS_MSG_SEQUENCE);
-	else if (!fingerprints.contains(parts[2], Qt::CaseInsensitive))
-		setSuccess(KGpgTransaction::TS_MSG_SEQUENCE);
-
-	return true;
-}
